---
title: Authentication
description: JWT, OTP, 2FA, and OAuth authentication for Django-CFG.
---

import { Callout } from 'nextra/components'

<Callout type="info">
This page has moved. See [Accounts & Authentication](../built-in-apps/user-management/accounts/index) for the full authentication documentation.
</Callout>

- [Overview](../built-in-apps/user-management/accounts/index)
- [OTP & Brute-Force Protection](../built-in-apps/user-management/accounts/otp)
- [JWT Configuration](../built-in-apps/user-management/accounts/jwt)
- [Two-Factor Auth (2FA)](../built-in-apps/user-management/accounts/two-factor)
- [OAuth (GitHub)](../built-in-apps/user-management/accounts/oauth)
